@@ -1,5 +1,7 @@
-use crate::Client;
+use crate::{Client, PKGX};
 use std::io::Read;
+use std::fmt::Error;
+use crate::pkg::CustomError;
 
 #[derive(Serialize, Deserialize, Debug)]
 pub struct Session {
@@ -40,7 +42,7 @@ impl Session {
   pub fn set(&self, c: &Client, s: &Session) -> String {
     let url = format!("http://{}:{}/v1/session/create", c.host, c.port);
     let payload = serde_json::to_string(s).unwrap();
-    println!("payload ------ {}", payload);
+    // println!("set session payload ------ {}", payload);
     let mut rsp = reqwest::Client::new()
       .put(&url)
       .body(payload)
@@ -49,12 +51,28 @@ impl Session {
     let mut body = String::new();
     // rsp.read_to_string(&mut body).map_err( |e| e.to_string());
     let session_set: SessionSet = rsp.json().unwrap();
-    println!("session_set ----------- {:?}", session_set);
+    // println!("session_set ----------- {:?}", session_set);
     session_set.ID
   }
+
+  pub fn renew(&self, c: &Client, sid: &str) -> Result<(), CustomError> {
+    let url = format!("http://{}:{}/v1/session/renew/{}", c.host, c.port, sid);
+    let mut rsp = reqwest::Client::new()
+      .put(&url)
+      .send()
+      .map_err( |e| e.to_string() ).unwrap();
+    let mut body = String::new();
+    rsp.read_to_string(&mut body).map_err( |e| e.to_string());
+    // println!("session renew: {:?}", body);
+    PKGX.debug_print(format!("session renew: {:?}", body).as_str());
+    if rsp.status().is_success() {
+      Ok(())
+    } else {
+      Err(CustomError(format!("renew session err: {}", sid)))
+    }
+  }
 }
 
 
 
 
-
